@@ -90,7 +90,7 @@ int main(int argc, char *argv[])
   QCommandLineOption disableTrayIcon(QStringList() << "d" << "disable-tray-icon",
 		QCoreApplication::translate("main.cpp", "Disable the system tray icon.  May be needed for system trays not compliant with the Freedesktop.org system tray specification.") );
   parser.addOption(disableTrayIcon);
-
+  
   parser.addHelpOption();
 
   QCommandLineOption useIconTheme(QStringList() << "i" << "icon-theme",
@@ -106,6 +106,14 @@ int main(int argc, char *argv[])
   QCommandLineOption startMinimized(QStringList() << "m" << "minimized",
 		QCoreApplication::translate("main.cpp", "Start the GUI minimized in the system tray.") );
   parser.addOption(startMinimized);
+  
+  QCommandLineOption disableMinimize(QStringList() << "M" << "disable-minimize",
+		QCoreApplication::translate("main.cpp", "Disable the minimize button. Use when you want to have the window manager have sole control of minimizing the interface.") );
+  parser.addOption(disableMinimize);  
+  
+  QCommandLineOption disableVPN(QStringList() << "n" << "disable-vpn",
+		QCoreApplication::translate("main.cpp", "Disable VPN support.") );
+  parser.addOption(disableVPN);  
 
   parser.addVersionOption();
 
