@@ -58,8 +58,9 @@ PropertiesEditor::PropertiesEditor(QWidget* parent, const arrayElement& ae)
   // Setup the address validator and apply it to any ui QLineEdit.
   // The lev validator will validate an IP address or up to one white space character (to allow
   // editing of the line edit).
-  QString s_ip4 = "(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9]?[0-9])";
-  QString s_ip6 = "(?:[0-9a-fA-F]{1,4})";
+  const QString s_ip4 = "(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9]?[0-9])";
+  const QString s_ip6 = "(?:[0-9a-fA-F]{1,4})";
+  const QString s_dom = "((?!-)[A-Za-z0-9-]{1,63}(?<!-)\\.)+[A-Za-z]{2,6}";
 
   // QLineEdits that allow single address
   QRegularExpression rx4("\\s?|^" + s_ip4 + "(?:\\." + s_ip4 + "){3}" + "$");
@@ -73,8 +74,8 @@ PropertiesEditor::PropertiesEditor(QWidget* parent, const arrayElement& ae)
   ui.lineEdit_ipv6gateway->setValidator(lev_6);
 
   // now QLineEdits that allow multiple addresses
-  QRegularExpression rx46("\\s?|((" + s_ip4 + "(?:\\." + s_ip4 + "){3}|" + s_ip6 + "(?::" + s_ip6 + "){7})(\\s*[,|;|\\s]\\s*))+");
-  QRegularExpressionValidator* lev_m = new QRegularExpressionValidator(rx46, this);
+  QRegularExpression rx46d("\\s?|((" + s_ip4 + "(?:\\." + s_ip4 + "){3}|"+ s_ip6 + "(?::" + s_ip6 + "){7}|" + s_dom + ")(\\s*[,|;|\\s]\\s*))+");
+  QRegularExpressionValidator* lev_m = new QRegularExpressionValidator(rx46d, this);
   ui.lineEdit_nameservers->setValidator(lev_m);
   ui.lineEdit_timeservers->setValidator(lev_m);
 
@@ -112,14 +113,20 @@ PropertiesEditor::PropertiesEditor(QWidget* parent, const arrayElement& ae)
   }
 
   // proxy page
-  if (! proxmap.value("Method").toString().isEmpty() ) {
-    ui.comboBox_proxymethod->setCurrentIndex(sl_proxy_method.indexOf(QRegularExpression(proxmap.value("Method").toString())) );
-  }
+  if (proxmap.value("Method").toString().isEmpty() )
+		ui.comboBox_proxymethod->setCurrentIndex(-1);
+	else
+		ui.comboBox_proxymethod->setCurrentIndex(sl_proxy_method.indexOf(QRegularExpression(proxmap.value("Method").toString())) );	
+
   ui.lineEdit_proxyservers->setText(proxmap.value("Servers").toStringList().join("\n") );
   ui.lineEdit_proxyexcludes->setText(proxmap.value("Excludes").toStringList().join("\n") );
   ui.lineEdit_proxyurl->setText(proxmap.value("URL").toString() );
-
-
+  
+  if (ui.comboBox_proxymethod->currentIndex() < 0)
+		ui.stackedWidget_proxy01->setCurrentIndex(0);
+	else	
+		ui.stackedWidget_proxy01->setCurrentIndex(ui.comboBox_proxymethod->currentIndex() );
+	
   // connect signals to slots
   connect(ui.toolButton_whatsthis, SIGNAL(clicked()), this, SLOT(showWhatsThis()));
   connect(ui.pushButton_resetpage, SIGNAL(clicked()), this, SLOT(resetPage()));
@@ -335,7 +342,7 @@ void PropertiesEditor::updateConfiguration()
     } // for
 
     vlist << QVariant::fromValue(QDBusVariant(dict) );
-    qDebug() << dict;
+    //qDebug() << dict;
     shared::processReply(iface_serv->callWithArgumentList(QDBus::AutoDetect, "SetProperty", vlist) );
   } // if proxy changed
 
